==> visualvm_2.0.6+dfsg.orig.tar.gz: visualvm-2.0.6/visualvm/caching.api/src/org/graalvm/visualvm/api/caching/Cache.java <==
/*
 * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.api.caching;

/**
 * An interface for cache
 * <p>
 * A cache is basically a map that can evict its entries according to defined TTL
 * or as a result of the user action
 * @author Jaroslav Bachorik
 */
abstract public class Cache<K,V> {
    /**
     * Retrieves an object from the cache by the given key<br/>
     * If there is no cached version of the object {@linkplain #cacheMiss(java.lang.Object) } is invoked
     * <p>
     * To obtain a cache one needs to call one of {@linkplain CacheFactory} methods
     * </p>
     * @param key The key identifying the object to be retrieved
     * @return Returns the cached object or NULL
     */
    abstract public V retrieveObject(K key);

    abstract public V invalidateObject(K key);

    /**
     * Property getter
     * @return Returns TTL interval in milliseconds
     */
    abstract public long getTTL();

    /**
     * Property setter
     * @param ttl TTL interval in milliseconds
     */
    abstract public void setTTL(long ttl);

}

==> visualvm_2.2.orig.tar.gz: visualvm-2.2/visualvm/caching.api/src/org/graalvm/visualvm/api/caching/Cache.java <==
/*
 * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.api.caching;

/**
 * An interface for cache
 * <p>
 * A cache is basically a map that can evict its entries according to defined TTL
 * or as a result of the user action
 * @author Jaroslav Bachorik
 */
abstract public class Cache<K,V> {
    /**
     * Retrieves an object from the cache by the given key<br>
     * If there is no cached version of the object {@linkplain EntryFactory#createEntry(Object)}  is invoked
     * <p>
     * To obtain a cache one needs to call one of {@linkplain CacheFactory} methods
     * </p>
     * @param key The key identifying the object to be retrieved
     * @return Returns the cached object or NULL
     */
    abstract public V retrieveObject(K key);

    abstract public V invalidateObject(K key);

    /**
     * Property getter
     * @return Returns TTL interval in milliseconds
     */
    abstract public long getTTL();

    /**
     * Property setter
     * @param ttl TTL interval in milliseconds
     */
    abstract public void setTTL(long ttl);

}
